@@ -70,10 +70,10 @@ void Export_pyste_src_Image()
         .def(init< const Magick::Geometry&, const Magick::Color& >())
         .def(init< const Magick::Blob& >())
         .def(init< const Magick::Blob&, const Magick::Geometry& >())
-        .def(init< const Magick::Blob&, const Magick::Geometry&, const unsigned int >())
-        .def(init< const Magick::Blob&, const Magick::Geometry&, const unsigned int, const std::string& >())
+        .def(init< const Magick::Blob&, const Magick::Geometry&, const size_t >())
+        .def(init< const Magick::Blob&, const Magick::Geometry&, const size_t, const std::string& >())
         .def(init< const Magick::Blob&, const Magick::Geometry&, const std::string& >())
-        .def(init< const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, const void* >())
+        .def(init< const size_t, const size_t, const std::string&, const MagickCore::StorageType, const void* >())
         .def(init< const Magick::Image& >())
         .def(init< MagickCore::Image* >())
         .def("adaptiveThreshold", &Magick::Image::adaptiveThreshold, Magick_Image_adaptiveThreshold_overloads_2_3())
@@ -86,15 +86,15 @@ void Export_pyste_src_Image()
         .def("blur", &Magick::Image::blur, Magick_Image_blur_overloads_0_2())
         .def("border", &Magick::Image::border, Magick_Image_border_overloads_0_1())
         .def("channel", &Magick::Image::channel)
-        .def("channelDepth", (void (Magick::Image::*)(const MagickCore::ChannelType, const unsigned int) )&Magick::Image::channelDepth)
-        .def("channelDepth", (unsigned int (Magick::Image::*)(const MagickCore::ChannelType) )&Magick::Image::channelDepth)
+        .def("channelDepth", (void (Magick::Image::*)(const MagickCore::ChannelType, const size_t) )&Magick::Image::channelDepth)
+        .def("channelDepth", (size_t (Magick::Image::*)(const MagickCore::ChannelType) )&Magick::Image::channelDepth)
         .def("charcoal", &Magick::Image::charcoal, Magick_Image_charcoal_overloads_0_2())
         .def("chop", &Magick::Image::chop)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("comment", (void (Magick::Image::*)(const std::string&) )&Magick::Image::comment)
         .def("compare", &Magick::Image::compare)
-        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const int, const int, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
+        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const ssize_t, const ssize_t, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const Magick::Geometry&, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const MagickCore::GravityType, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("contrast", &Magick::Image::contrast)
@@ -111,18 +111,18 @@ void Export_pyste_src_Image()
         .def("equalize", &Magick::Image::equalize)
         .def("erase", &Magick::Image::erase)
         .def("flip", &Magick::Image::flip)
-        .def("floodFillColor", (void (Magick::Image::*)(const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::floodFillColor)
+        .def("floodFillColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&) )&Magick::Image::floodFillColor)
-        .def("floodFillColor", (void (Magick::Image::*)(const unsigned int, const unsigned int, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
+        .def("floodFillColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillOpacity", &Magick::Image::floodFillOpacity)
-        .def("floodFillTexture", (void (Magick::Image::*)(const unsigned int, const unsigned int, const Magick::Image&) )&Magick::Image::floodFillTexture)
+        .def("floodFillTexture", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&) )&Magick::Image::floodFillTexture)
-        .def("floodFillTexture", (void (Magick::Image::*)(const unsigned int, const unsigned int, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
+        .def("floodFillTexture", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
         .def("flop", &Magick::Image::flop)
         .def("frame", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::frame, Magick_Image_frame_overloads_0_1())
-        .def("frame", (void (Magick::Image::*)(const unsigned int, const unsigned int, const int, const int) )&Magick::Image::frame, Magick_Image_frame_overloads_2_4())
+        .def("frame", (void (Magick::Image::*)(const size_t, const size_t, const ssize_t, const ssize_t) )&Magick::Image::frame, Magick_Image_frame_overloads_2_4())
         .def("gamma", (void (Magick::Image::*)(const double) )&Magick::Image::gamma)
         .def("gamma", (void (Magick::Image::*)(const double, const double, const double) )&Magick::Image::gamma)
         .def("gaussianBlur", &Magick::Image::gaussianBlur)
@@ -148,15 +148,15 @@ void Export_pyste_src_Image()
         .def("read", (void (Magick::Image::*)(const Magick::Geometry&, const std::string&) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&) )&Magick::Image::read)
-        .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const unsigned int) )&Magick::Image::read)
-        .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const unsigned int, const std::string&) )&Magick::Image::read)
+        .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const size_t) )&Magick::Image::read)
+        .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const size_t, const std::string&) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const std::string&) )&Magick::Image::read)
-        .def("read", (void (Magick::Image::*)(const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, const void*) )&Magick::Image::read)
+        .def("read", (void (Magick::Image::*)(const size_t, const size_t, const std::string&, const MagickCore::StorageType, const void*) )&Magick::Image::read)
         .def("reduceNoise", (void (Magick::Image::*)() )&Magick::Image::reduceNoise)
         .def("reduceNoise", (void (Magick::Image::*)(const double) )&Magick::Image::reduceNoise)
         .def("resize", &Magick::Image::resize)
         .def("roll", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::roll)
-        .def("roll", (void (Magick::Image::*)(const unsigned int, const unsigned int) )&Magick::Image::roll)
+        .def("roll", (void (Magick::Image::*)(const size_t, const size_t) )&Magick::Image::roll)
         .def("rotate", &Magick::Image::rotate)
         .def("sample", &Magick::Image::sample)
         .def("scale", &Magick::Image::scale)
@@ -182,17 +182,17 @@ void Export_pyste_src_Image()
         .def("write", (void (Magick::Image::*)(const std::string&) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&) )&Magick::Image::write)
-        .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&, const unsigned int) )&Magick::Image::write)
-        .def("write", (void (Magick::Image::*)(const int, const int, const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
+        .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&, const size_t) )&Magick::Image::write)
+        .def("write", (void (Magick::Image::*)(const ssize_t, const ssize_t, const size_t, const size_t, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
         .def("zoom", &Magick::Image::zoom)
         .def("adjoin", (void (Magick::Image::*)(const bool) )&Magick::Image::adjoin)
         .def("adjoin", (bool (Magick::Image::*)() const)&Magick::Image::adjoin)
         .def("antiAlias", (void (Magick::Image::*)(const bool) )&Magick::Image::antiAlias)
         .def("antiAlias", (bool (Magick::Image::*)() )&Magick::Image::antiAlias)
-        .def("animationDelay", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::animationDelay)
-        .def("animationDelay", (unsigned int (Magick::Image::*)() const)&Magick::Image::animationDelay)
-        .def("animationIterations", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::animationIterations)
-        .def("animationIterations", (unsigned int (Magick::Image::*)() const)&Magick::Image::animationIterations)
+        .def("animationDelay", (void (Magick::Image::*)(const size_t) )&Magick::Image::animationDelay)
+        .def("animationDelay", (size_t (Magick::Image::*)() const)&Magick::Image::animationDelay)
+        .def("animationIterations", (void (Magick::Image::*)(const size_t) )&Magick::Image::animationIterations)
+        .def("animationIterations", (size_t (Magick::Image::*)() const)&Magick::Image::animationIterations)
         .def("attribute", (void (Magick::Image::*)(const std::string, const std::string) )&Magick::Image::attribute)
         .def("attribute", (std::string (Magick::Image::*)(const std::string) )&Magick::Image::attribute)
         .def("backgroundColor", (void (Magick::Image::*)(const Magick::Color&) )&Magick::Image::backgroundColor)
@@ -222,10 +222,10 @@ void Export_pyste_src_Image()
         .def("clipMask", (Magick::Image (Magick::Image::*)() const)&Magick::Image::clipMask)
         .def("colorFuzz", (void (Magick::Image::*)(const double) )&Magick::Image::colorFuzz)
         .def("colorFuzz", (double (Magick::Image::*)() const)&Magick::Image::colorFuzz)
-        .def("colorMap", (void (Magick::Image::*)(const unsigned int, const Magick::Color&) )&Magick::Image::colorMap)
-        .def("colorMap", (Magick::Color (Magick::Image::*)(const unsigned int) const)&Magick::Image::colorMap)
-        .def("colorMapSize", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::colorMapSize)
-        .def("colorMapSize", (unsigned int (Magick::Image::*)() )&Magick::Image::colorMapSize)
+        .def("colorMap", (void (Magick::Image::*)(const size_t, const Magick::Color&) )&Magick::Image::colorMap)
+        .def("colorMap", (Magick::Color (Magick::Image::*)(const size_t) const)&Magick::Image::colorMap)
+        .def("colorMapSize", (void (Magick::Image::*)(const size_t) )&Magick::Image::colorMapSize)
+        .def("colorMapSize", (size_t (Magick::Image::*)() )&Magick::Image::colorMapSize)
         .def("colorSpace", (void (Magick::Image::*)(const MagickCore::ColorspaceType) )&Magick::Image::colorSpace)
         .def("colorSpace", (MagickCore::ColorspaceType (Magick::Image::*)() const)&Magick::Image::colorSpace)
         .def("columns", &Magick::Image::columns)
@@ -242,8 +242,8 @@ void Export_pyste_src_Image()
         .def("defineSet", (bool (Magick::Image::*)(const std::string&, const std::string&) const)&Magick::Image::defineSet)
         .def("density", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::density)
         .def("density", (Magick::Geometry (Magick::Image::*)() const)&Magick::Image::density)
-        .def("depth", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::depth)
-        .def("depth", (unsigned int (Magick::Image::*)() const)&Magick::Image::depth)
+        .def("depth", (void (Magick::Image::*)(const size_t) )&Magick::Image::depth)
+        .def("depth", (size_t (Magick::Image::*)() const)&Magick::Image::depth)
         .def("directory", &Magick::Image::directory)
         .def("endian", (void (Magick::Image::*)(const MagickCore::EndianType) )&Magick::Image::endian)
         .def("endian", (MagickCore::EndianType (Magick::Image::*)() const)&Magick::Image::endian)
@@ -266,8 +266,8 @@ void Export_pyste_src_Image()
         .def("format", &Magick::Image::format)
         .def("gamma", (double (Magick::Image::*)() const)&Magick::Image::gamma)
         .def("geometry", &Magick::Image::geometry)
-        .def("gifDisposeMethod", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::gifDisposeMethod)
-        .def("gifDisposeMethod", (unsigned int (Magick::Image::*)() const)&Magick::Image::gifDisposeMethod)
+        .def("gifDisposeMethod", (void (Magick::Image::*)(const size_t) )&Magick::Image::gifDisposeMethod)
+        .def("gifDisposeMethod", (size_t (Magick::Image::*)() const)&Magick::Image::gifDisposeMethod)
         .def("iccColorProfile", (void (Magick::Image::*)(const Magick::Blob&) )&Magick::Image::iccColorProfile)
         .def("iccColorProfile", (Magick::Blob (Magick::Image::*)() const)&Magick::Image::iccColorProfile)
         .def("interlaceType", (void (Magick::Image::*)(const MagickCore::InterlaceType) )&Magick::Image::interlaceType)
@@ -286,8 +286,8 @@ void Export_pyste_src_Image()
         .def("matteColor", (void (Magick::Image::*)(const Magick::Color&) )&Magick::Image::matteColor)
         .def("matteColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::matteColor)
         .def("meanErrorPerPixel", &Magick::Image::meanErrorPerPixel)
-        .def("modulusDepth", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::modulusDepth)
-        .def("modulusDepth", (unsigned int (Magick::Image::*)() const)&Magick::Image::modulusDepth)
+        .def("modulusDepth", (void (Magick::Image::*)(const size_t) )&Magick::Image::modulusDepth)
+        .def("modulusDepth", (size_t (Magick::Image::*)() const)&Magick::Image::modulusDepth)
         .def("montageGeometry", &Magick::Image::montageGeometry)
         .def("monochrome", (void (Magick::Image::*)(const bool) )&Magick::Image::monochrome)
         .def("monochrome", (bool (Magick::Image::*)() const)&Magick::Image::monochrome)
@@ -299,27 +299,27 @@ void Export_pyste_src_Image()
         .def("penColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::penColor)
         .def("penTexture", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::penTexture)
         .def("penTexture", (Magick::Image (Magick::Image::*)() const)&Magick::Image::penTexture)
-        .def("pixelColor", (void (Magick::Image::*)(const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::pixelColor)
-        .def("pixelColor", (Magick::Color (Magick::Image::*)(const unsigned int, const unsigned int) const)&Magick::Image::pixelColor)
+        .def("pixelColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&) )&Magick::Image::pixelColor)
+        .def("pixelColor", (Magick::Color (Magick::Image::*)(const ssize_t, const ssize_t) const)&Magick::Image::pixelColor)
         .def("profile", (void (Magick::Image::*)(const std::string, const Magick::Blob&) )&Magick::Image::profile)
         .def("profile", (Magick::Blob (Magick::Image::*)(const std::string) const)&Magick::Image::profile)
-        .def("quality", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::quality)
-        .def("quality", (unsigned int (Magick::Image::*)() const)&Magick::Image::quality)
-        .def("quantizeColors", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::quantizeColors)
-        .def("quantizeColors", (unsigned int (Magick::Image::*)() const)&Magick::Image::quantizeColors)
+        .def("quality", (void (Magick::Image::*)(const size_t) )&Magick::Image::quality)
+        .def("quality", (size_t (Magick::Image::*)() const)&Magick::Image::quality)
+        .def("quantizeColors", (void (Magick::Image::*)(const size_t) )&Magick::Image::quantizeColors)
+        .def("quantizeColors", (size_t (Magick::Image::*)() const)&Magick::Image::quantizeColors)
         .def("quantizeColorSpace", (void (Magick::Image::*)(const MagickCore::ColorspaceType) )&Magick::Image::quantizeColorSpace)
         .def("quantizeColorSpace", (MagickCore::ColorspaceType (Magick::Image::*)() const)&Magick::Image::quantizeColorSpace)
         .def("quantizeDither", (void (Magick::Image::*)(const bool) )&Magick::Image::quantizeDither)
         .def("quantizeDither", (bool (Magick::Image::*)() const)&Magick::Image::quantizeDither)
-        .def("quantizeTreeDepth", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::quantizeTreeDepth)
-        .def("quantizeTreeDepth", (unsigned int (Magick::Image::*)() const)&Magick::Image::quantizeTreeDepth)
+        .def("quantizeTreeDepth", (void (Magick::Image::*)(const size_t) )&Magick::Image::quantizeTreeDepth)
+        .def("quantizeTreeDepth", (size_t (Magick::Image::*)() const)&Magick::Image::quantizeTreeDepth)
         .def("renderingIntent", (void (Magick::Image::*)(const MagickCore::RenderingIntent) )&Magick::Image::renderingIntent)
         .def("renderingIntent", (MagickCore::RenderingIntent (Magick::Image::*)() const)&Magick::Image::renderingIntent)
         .def("resolutionUnits", (void (Magick::Image::*)(const MagickCore::ResolutionType) )&Magick::Image::resolutionUnits)
         .def("resolutionUnits", (MagickCore::ResolutionType (Magick::Image::*)() const)&Magick::Image::resolutionUnits)
         .def("rows", &Magick::Image::rows)
-        .def("scene", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::scene)
-        .def("scene", (unsigned int (Magick::Image::*)() const)&Magick::Image::scene)
+        .def("scene", (void (Magick::Image::*)(const size_t) )&Magick::Image::scene)
+        .def("scene", (size_t (Magick::Image::*)() const)&Magick::Image::scene)
         .def("signature", &Magick::Image::signature, Magick_Image_signature_overloads_0_1())
         .def("size", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::size)
         .def("size", (Magick::Geometry (Magick::Image::*)() const)&Magick::Image::size)
@@ -334,16 +334,16 @@ void Export_pyste_src_Image()
         .def("strokeLineCap", (MagickCore::LineCap (Magick::Image::*)() const)&Magick::Image::strokeLineCap)
         .def("strokeLineJoin", (void (Magick::Image::*)(const MagickCore::LineJoin) )&Magick::Image::strokeLineJoin)
         .def("strokeLineJoin", (MagickCore::LineJoin (Magick::Image::*)() const)&Magick::Image::strokeLineJoin)
-        .def("strokeMiterLimit", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::strokeMiterLimit)
-        .def("strokeMiterLimit", (unsigned int (Magick::Image::*)() const)&Magick::Image::strokeMiterLimit)
+        .def("strokeMiterLimit", (void (Magick::Image::*)(const size_t) )&Magick::Image::strokeMiterLimit)
+        .def("strokeMiterLimit", (size_t (Magick::Image::*)() const)&Magick::Image::strokeMiterLimit)
         .def("strokePattern", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::strokePattern)
         .def("strokePattern", (Magick::Image (Magick::Image::*)() const)&Magick::Image::strokePattern)
         .def("strokeWidth", (void (Magick::Image::*)(const double) )&Magick::Image::strokeWidth)
         .def("strokeWidth", (double (Magick::Image::*)() const)&Magick::Image::strokeWidth)
-        .def("subImage", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::subImage)
-        .def("subImage", (unsigned int (Magick::Image::*)() const)&Magick::Image::subImage)
-        .def("subRange", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::subRange)
-        .def("subRange", (unsigned int (Magick::Image::*)() const)&Magick::Image::subRange)
+        .def("subImage", (void (Magick::Image::*)(const size_t) )&Magick::Image::subImage)
+        .def("subImage", (size_t (Magick::Image::*)() const)&Magick::Image::subImage)
+        .def("subRange", (void (Magick::Image::*)(const size_t) )&Magick::Image::subRange)
+        .def("subRange", (size_t (Magick::Image::*)() const)&Magick::Image::subRange)
         .def("textEncoding", (void (Magick::Image::*)(const std::string&) )&Magick::Image::textEncoding)
         .def("textEncoding", (std::string (Magick::Image::*)() const)&Magick::Image::textEncoding)
         .def("tileName", (void (Magick::Image::*)(const std::string&) )&Magick::Image::tileName)
